@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Overlay;
-$Footprintless::Overlay::VERSION = '1.22';
+$Footprintless::Overlay::VERSION = '1.23';
 # ABSTRACT: An overlay manager
 # PODNAME: Footprintless::Overlay
 
@@ -53,7 +53,10 @@ sub _dirs_template {
             $base_dir = File::Spec->catdir( $unpack_dir, $base_dir );
         }
         if ($template_dir) {
-            $template_dir = File::Spec->catdir( $unpack_dir, $template_dir );
+            $template_dir =
+                ref($template_dir) eq 'ARRAY'
+                ? [ map { File::Spec->catdir( $unpack_dir, $_ ) } @$template_dir ]
+                : File::Spec->catdir( $unpack_dir, $template_dir );
         }
     }
 
@@ -215,7 +218,7 @@ Footprintless::Overlay - An overlay manager
 
 =head1 VERSION
 
-version 1.22
+version 1.23
 
 =head1 SYNOPSIS
 
@@ -315,7 +318,7 @@ A more complex example:
         }
     }
 
-You can even store your overlay base/template content in a resource.  When
+An overlay can obtain base/template content from a resource.  When
 initialize or update are called, the resource will be downloaded (if not
 already local) and extracted to a temp folder.  The C<base_dir> and
 C<template_dir> paths will be appended to the extract temp folder:
@@ -333,6 +336,24 @@ C<template_dir> paths will be appended to the extract temp folder:
         to_dir => '/opt/foo/tomcat'
     }
 
+An overlay can have multiple template folders.  If it does, they will
+be processed in the order they are listed:
+
+    overlay => {
+        base_dir => 'base',
+        clean => [
+            '/opt/tomcat/'
+        ],
+        hostname => 'localhost',
+        key => 'T',
+        os => 'linux',
+        template_dir => [
+            'first/template_dir',
+            'second/template_dir',
+        ],
+        to_dir => '/opt/foo/tomcat'
+    }
+
 =head1 CONSTRUCTORS
 
 =head2 new($entity, $coordinate)
